#include <iostream>
#include <string>
#include <cassert>
#include <fstream>

const std::string FILENAME("trip");

std::ifstream fin(FILENAME + ".in");
std::ofstream fout(FILENAME + ".out");

const int MaxN = 2e5 + 5;
const int Inf = 1e9;
const int MaxBlocks = 10000;
const int MaxLog = 20;

int arr[MaxN], pref[MaxN];
int n, q;

int char_to_int(char ch) {
    if (ch == 'o') return 1;
    if (ch == '-') return 0;
    if (ch == 'x') return -1;
    return 0;
}

void compute_pref(int n, int arr[], int pref[]) {
    pref[0] = 0;
    for (int i = 1; i <= n; ++i) {
        pref[i] = pref[i - 1] + arr[i];
    }
}

namespace SqrtDecomp {
    int block_size, nr_blocks;
    int block_min[MaxBlocks], block_max[MaxBlocks];
    int in_block[MaxN];
    int lazy[MaxBlocks];
    int val[MaxN];

    void set_blocks(int b) {
        block_size = b;
        for (int i = 1; i <= n; ++i) {
            in_block[i] = (i - 1) / block_size;
        }
        nr_blocks = in_block[n] + 1;
    }

    void build(int *arr) {
        for (int i = 0; i < nr_blocks; ++i) {
            block_min[i] = Inf;
            block_max[i] = -Inf;
            lazy[i] = 0;
        }
        for (int i = 1; i <= n; ++i) {
            val[i] = arr[i];
            block_min[in_block[i]] = std::min(block_min[in_block[i]], val[i]);
            block_max[in_block[i]] = std::max(block_max[in_block[i]], val[i]);
        }
    }

    std::pair<int,int> get_block_limits(int block) {
        return {block * block_size + 1, std::min(n, (block + 1) * block_size)};
    }

    void update_block(int block) {
        std::pair<int,int> left_block = get_block_limits(block);
        block_min[block] = Inf;
        block_max[block] = -Inf;
        for (int i = left_block.first; i <= left_block.second; ++i) {
            val[i] += lazy[block];
            block_min[block] = std::min(block_min[block], val[i]);
            block_max[block] = std::max(block_max[block], val[i]);
        }
        lazy[block] = 0;
    }

    void add_suf(int l, int x) {
        int block = l / block_size;
        std::pair<int,int> left_block = get_block_limits(block);
        
        for (int i = l; i <= left_block.second; ++i) {
            val[i] += x;
        }
        update_block(block);

        for (int b = block + 1; b < nr_blocks; ++b) {
            lazy[b] += x;
            block_min[b] += x;
            block_max[b] += x;
        }

    }

    std::pair<int,int> query(int l, int r) {
        int min_val = Inf, max_val = -Inf;

        

        int left_block = in_block[l];
        int right_block = in_block[r];

        if (left_block == right_block) {
            update_block(left_block);
            for (int i = l; i <= r; ++i) {
                min_val = std::min(min_val, val[i]);
                max_val = std::max(max_val, val[i]);
            }
        } else {
            update_block(left_block);
            update_block(right_block);
            std::pair<int,int> lb_limits = get_block_limits(left_block);
            std::pair<int,int> rb_limits = get_block_limits(right_block);
            for (int i = l; i <= lb_limits.second; ++i) {
                min_val = std::min(min_val, val[i]);
                max_val = std::max(max_val, val[i]);
            }
            for (int i = rb_limits.first; i <= r; ++i) {
                min_val = std::min(min_val, val[i]);
                max_val = std::max(max_val, val[i]);
            }
            for (int i = left_block + 1; i < right_block; ++i) {
                min_val = std::min(min_val, block_min[i]);
                max_val = std::max(max_val, block_max[i]);
            }
        }
        return {min_val, max_val};
    }
}

int main() {
    fin >> n;

    for (int i = 1; i <= n; ++i) {
        char ch;
        fin >> ch;
        arr[i] = char_to_int(ch);
    }
    compute_pref(n, arr, pref);
    
    SqrtDecomp::set_blocks(500);
    SqrtDecomp::build(pref);

    fin >> q;

    while (q--) {
        int type;
        fin >> type;
        if (type == 1) {
            int position;
            char  cvalue;
            fin >> position >> cvalue;
            int value  = char_to_int(cvalue);
            int old_value = arr[position];
            int to_add = value - old_value;
            arr[position] = value;
            SqrtDecomp::add_suf(position, to_add);
        } else {
            int l1, r1, l2, r2, k;
            fin >> l1 >> r1 >> l2 >> r2 >> k;
            
            std::pair<int,int> left_range = SqrtDecomp::query(l1 - 1, r1 - 1);
            std::pair<int,int> right_range = SqrtDecomp::query(l2, r2);

            int min_diff = right_range.first - left_range.second;
            int max_diff = right_range.second - left_range.first;
           
            fout << (min_diff <= k && k <= max_diff) << '\n';
        }
    }
    fin.close();
    fout.close();
    return 0;

}